function F = free_energy_tension(ksi_e_p,ksi_R_p,e_tr_e,e,T,ksi_i,eps_tr_i);

global K E_aus E_mar E_R sig_reo To deltaS Ms Mf As Af ...
       E_int E_inter2 E_inter1 E_int_R deltaS_R Rs Rf 

eps_tr_i = [eps_tr_i;-eps_tr_i/2;-eps_tr_i/2;0;0;0]; %initial tensor of transformation strain in Kelvin notation:[e11; e22; e33; sqrt(2)*e23; sqrt(2)*e13; sqrt(2)*e12]
ksi_e = (tanh(ksi_e_p) + 1)/2;  % final volume fraction of martensite, transformation of unconstrained ksi_e_p to constrained ksi_e
ksi_R = (tanh(ksi_R_p) + 1)/2; % final volume fraction of R-phase in A, transformation of unconstrained ksi_R_p to constrained ksi_e
eps_tr_e = [e_tr_e(1);-e_tr_e(1)/2;-e_tr_e(1)/2;0;0;0];
eps_tr_e = eps_tr_e./(norm_e2(eps_tr_e) + 1/(norm_e2(eps_tr_e) +1)); %final tensor of transformation strain in Kelvin notation, 
%Young modulus of A+R+M - Reuss model:
E_AR = E_aus*E_R/((1-ksi_R)*E_R + ksi_R*E_aus);
E = E_AR*E_mar/((1-ksi_e)*E_mar + ksi_e*E_AR);
%Energetic terms:
E_elast = 1/2*(e - ksi_e.*eps_tr_e(1))^2*E; %elastic energy
E_chem = (T - To)*deltaS*ksi_e + (1-ksi_e)*deltaS_R*ksi_R*(T- (Rs + (Rf-Rs)*ksi_R/2));  % + Uo_aus + (T - To)*S_aus ...chemical energy
E_interM = ksi_e*E_int*K*(norm_e2(eps_tr_e))^2/(1-norm_e2(eps_tr_e)^4); % regularization term for ||eps_tr|| < 1, hardening in martensite
E_inter_ksi = ((ksi_e_p/E_inter2).^2).*(ksi_e_p >0)+((ksi_e_p/E_inter1).^4).*(ksi_e_p <=0); %regularization term for 0 < ksi < 1
E_inter_R = (((ksi_R_p/E_int_R).^2).*(ksi_R_p >0)+((ksi_R_p/E_int_R).^2).*(ksi_R_p <=0))*(1-ksi_e); %regularization term for 0 < ksi_R < 1
%Dissipated energy:
if ksi_e <= ksi_i, % reverse transformation
    E_dis1 = ksi_e*sig_reo*norm(eps_tr_i - eps_tr_e); 
    E_dis2 = (ksi_i-ksi_e)*sig_reo*norm(eps_tr_i); 
    E_dis3 = deltaS*((Af-To)*(ksi_i-ksi_e) + (As-Af)*(ksi_i^2-ksi_e^2)/2);
    E_dis = E_dis1 + E_dis2 + E_dis3;
else % forward transformation
    E_dis1 = ksi_e*sig_reo*norm(eps_tr_i.*(ksi_i/ksi_e) - eps_tr_e); 
    E_dis3 = deltaS*((To-Ms)*(ksi_e-ksi_i) + (Ms-Mf)*(ksi_e^2-ksi_i^2)/2);
    E_dis = E_dis1 + E_dis3;
end;

F = E_elast + E_chem + E_interM + E_dis + E_inter_ksi + E_inter_R;
return



