function [sig_e,internal_variables] = stress_strain(e,T,internal_variables);
global E_aus E_mar E_R options_iter 

%internal variables of element
ksi_i = internal_variables.ksi;
eps_tr_i = internal_variables.eps_tr;
ksi_R = internal_variables.ksi_R;
%mapping of internal variables to unconstrained
ksi_i_p = atanh(2*ksi_i - 1);
ksi_R_p = atanh(2*ksi_R - 1);
eps_tr_ten = [eps_tr_i;-eps_tr_i/2;-eps_tr_i/2;0;0;0];     
N_eps = norm_e2(eps_tr_ten);
koef = (1-N_eps - (-3.*N_eps.^2 + 2.*N_eps +1).^0.5)./(2.*N_eps -2);
if N_eps > 0,
        eps_tr_i_p = koef.*eps_tr_i./N_eps;
else
        eps_tr_i_p = eps_tr_i;
end;
% initial values for minimization
ksi_i_p = round(ksi_i_p*100)/100;
ksi_R_p = round(ksi_R_p*100)/100;
eps_tr_i_p = round(eps_tr_i_p.*1000)./1000;
% 1. unconstrained minimization with respect to ksi and eps_tr - simplex 
[result,F] = fminsearch(@(x) free_energy_tension(x(1),ksi_R_p,x(2),...
            e,T,ksi_i,eps_tr_i),...
            [ksi_i_p eps_tr_i_p],options_iter);
% transformation of unconstrained variables to constrained ones
ksi_e = (tanh(result(1)) + 1)/2;
e_tr_e = result(2);
eps_tr_e = [e_tr_e(1);-e_tr_e(1)/2;-e_tr_e(1)/2;0;0;0];
eps_tr_e = eps_tr_e./(norm_e2(eps_tr_e) + 1/(norm_e2(eps_tr_e) +1)); 
% 2. unconstrained minimization with respect to ksi_R - simplex 
[result,F] = fminsearch(@(x) free_energy_tension(result(1),x(1),result(2),...
            e,T,ksi_e,eps_tr_e(1)),...
            [ksi_R_p],options_iter);
ksi_R = (tanh(result(1)) + 1)/2;
% stress calculation
E_AR = E_aus*E_R/((1-ksi_R)*E_R + ksi_R*E_aus);
E = E_AR*E_mar/((1-ksi_e)*E_mar + ksi_e*E_AR);
sig_e = (e - ksi_e.*eps_tr_e(1))*E;
% internal variables storage
internal_variables.ksi = ksi_e;
internal_variables.eps_tr = eps_tr_e(1);
internal_variables.ksi_R = ksi_R;
return